#!/usr/bin/python

import Poem.django_logging
import base64
import httplib
import logging
import os
import ssl
import string

from Poem import settings
from Poem.poem import models
from django.db import connection, transaction
from xml.etree import ElementTree
from urlparse import urlparse

logging.basicConfig(format='%(filename)s[%(process)s]: %(levelname)s %(message)s', level=logging.INFO)
logger = logging.getLogger("POEM")

def main():
    "Parses service flavours list from GOCDB"

    Feed_List = None
    fos = []

    try:
        for fp in [settings.HOST_CERT, settings.HOST_KEY]:
            if not os.path.exists(fp):
                raise IOError("invalid path %s" % (fp))
            else:
                fos.append(open(fp))
    except IOError as e:
        logger.error(e)
        raise SystemExit(1)
    for fo in fos:
        fo.close()

    o = urlparse(settings.SERVICETYPE_URL)
    try:
        if o.scheme.startswith('https'):
            context = ssl.create_default_context(cafile=settings.CAFILE,
                                                 capath=settings.CAPATH)
            conn = httplib.HTTPSConnection(host=o.netloc, \
                                           key_file=settings.HOST_KEY, cert_file=settings.HOST_CERT, \
                                           timeout=60,
                                           context=context)
        else:
            conn = httplib.HTTPConnection(host=o.netloc)

        headers = dict()
        if settings.HTTPAUTH:
            userpass = base64.b64encode(settings.HTTPUSER + ':' + settings.HTTPPASS)
            headers={'Authorization': 'Basic ' + userpass}

        conn.request('GET', o.path + '?' + o.query, headers=headers)
        ret = conn.getresponse().read()

    except Exception as e:
        logger.error("Error service flavours feed - %s" % (repr(e)))
        raise SystemExit(1)

    try:
        Root = ElementTree.XML(ret)
    except Exception as e:
        logger.error("Error parsing service flavours - %s" % (e))
        raise SystemExit(1)

    elements = Root.findall("SERVICE_TYPE")
    if not elements:
        logger.error("Error parsing service flavours")
        raise SystemExit(1)

    Feed_List = []
    for element in elements:
        Element_List = {}
        if element.getchildren():
            for child_element in element.getchildren():
                Element_List[string.lower(child_element.tag)] = (child_element.text)
        Feed_List.append(Element_List)


    sfindb = set([(sf.name, sf.description) for sf in models.ServiceFlavour.objects.all()])
    if len(sfindb) != len(Feed_List):
        sfs = set([(feed['service_type_name'], feed['service_type_desc']) \
                for feed in Feed_List])
        cur = connection.cursor()
        try:
            if len(sfindb) < len(Feed_List):
                cur.executemany('INSERT INTO poem_serviceflavour VALUES (?,?)', \
                        sfs.difference(sfindb))
                logger.info("Added %d service flavours" %\
                            (len(Feed_List) - len(sfindb)))
            elif len(sfindb) > len(Feed_List):
                cur.executemany('DELETE FROM poem_serviceflavour WHERE name IN (?,?)', \
                        sfindb.difference(sfs))
                logger.info("Deleted %d service flavours" %\
                            (len(sfindb) - len(Feed_List)))
            transaction.commit_unless_managed()
            connection.close()
        except Exception as e:
            logger.error("database operations failed - %s" % e)
    else:
        logger.info("Service Flavours database is up to date")

main()
